.. _symptomen:

.. raw:: html

    <br>

.. title:: symptomen

symptomen
=========

.. raw:: html

    <br>

.. include:: vergiftiging

.. include:: bijwerking.rst

.. include:: dopamine

.. include:: ontwenning.rst
